from emod_api import schema_to_class as s2c
import json

#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch

def ActiveDiagnostic(
        camp,
        trigger_treatment_list,
        active_sensitivity=1.0,
        active_specificity=1.0,
        pos_event= 'TBTestPositive',
        treatment_fraction= 1,
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='TB Diagnosis Active Simple'):
    """
    ActiveDiagnostic
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    # First, get the objects
    schema_path = camp.schema_path
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    intervention = s2c.get_class_with_defaults( "ActiveDiagnostic", schema_path )

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV", schema_path )
    #meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=duration
    meta_intervention.Trigger_Condition_List.extend( trigger_treatment_list )
    meta_intervention.Blackout_Period = black_period
    meta_intervention.Blackout_Event_Trigger = black_trigger
    meta_intervention.Property_Restrictions.extend ( property_restrictions_list )
    meta_intervention.Actual_IndividualIntervention_Config = intervention
    meta_intervention.pop("Actual_NodeIntervention_Config")
    meta_intervention.pop("Node_Property_Restrictions")
    meta_intervention.pop("Property_Restrictions_Within_Node")

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_intervention
    event.Start_Day = float(start_day)

    # Third, do the actual settings
    intervention.Base_Sensitivity = active_sensitivity
    intervention.Base_Specificity = active_specificity
    intervention.Treatment_Fraction = treatment_fraction
    #intervention.Days_To_Diagnosis = 0
    intervention.Event_Or_Config = 'Event'
    # TBD: We have to map ad-hoc events to GP_EVENT_xxx before this. ad-hoc events must be accumulated centrally (in campaign)
    # so subsequent ad-hoc events don't get mapped to new events but the 'cached' value.
    use_event = camp.get_event(pos_event)
    intervention.Positive_Diagnosis_Event = use_event
    #intervention.Duplicate_Policy = dupe_policy

    # Fourth/finally, purge the schema bits
    coordinator.finalize()
    intervention.finalize()
    meta_intervention.finalize()
    event.finalize()
    event["Name"] = event_name
    event["Listening"] = list()
    event["Listening"].extend( trigger_treatment_list )
    event["Listening"].append( black_trigger )
    event["Broadcasting"] = [ pos_event ]

    return event

def new_intervention_as_file( start_day, filename=None ):
    campaign = {}
    campaign["Events"] = []
    campaign["Events"].append( new_intervention( start_day, vaccine_type, iv_name ) )
    if filename is None:
        filename = "active_diag.json"
    with open( filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return filename

