from emod_api import schema_to_class as s2c
import json

#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch

def get_thresh( name, low, high, camp ):
    thresh = {}
    thresh["Event"] = camp.get_event( name )
    thresh["Low"] = low
    thresh["High"] = high
    return thresh

def get_threshes( group_names, camp ):
    threshes = list()
    threshes.append( get_thresh( group_names[0], 0, 200, camp ) )
    threshes.append( get_thresh( group_names[1], 200, 350, camp ) )
    threshes.append( get_thresh( group_names[2], 350, 500, camp ) )
    threshes.append( get_thresh( group_names[3], 500, 20000, camp ) )
    return threshes
 
def CD4Diag(
        camp,
        trigger_treatment_list,
        event_200='Below200',
        event_350='Below350',
        event_500='Below500',
        event_above_500='Above500',
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='CD4 Diagnostic'):
    """
    ART
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    # First, get the objects
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    intervention = s2c.get_class_with_defaults( "CD4Diagnostic", schema_path )

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV", schema_path )
    #meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=duration
    meta_intervention.Trigger_Condition_List.extend(trigger_treatment_list)
    meta_intervention.Blackout_Period = black_period
    meta_intervention.Blackout_Event_Trigger = black_trigger
    meta_intervention.Property_Restrictions.extend(property_restrictions_list)
    meta_intervention.Actual_IndividualIntervention_Config = intervention
    meta_intervention.pop( "Actual_NodeIntervention_Config" )
    meta_intervention.pop("Node_Property_Restrictions")
    meta_intervention.pop("Property_Restrictions_Within_Node")

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_intervention
    event.Start_Day = float(start_day)

    # Third, do the actual settings
        
    intervention.CD4_Thresholds = get_threshes( [ event_200, event_350, event_500, event_above_500 ], camp )
    #intervention.Duplicate_Policy = dupe_policy

    # Fourth/finally, purge the schema bits
    coordinator.finalize()
    intervention.finalize()
    meta_intervention.finalize()
    event.finalize()
    event["Name"] = event_name
    event["Listening"] = list()
    event["Listening"].extend( trigger_treatment_list )
    event["Listening"].append( black_trigger )

    return event

def new_intervention_as_file( start_day, filename=None ):
    campaign = {}
    campaign["Events"] = []
    campaign["Events"].append( new_intervention( start_day, vaccine_type, iv_name ) )
    if filename is None:
        filename = "cd4.json"
    with open( filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return filename

