from emod_api import schema_to_class as s2c
import json

#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch

def HSB(
        camp,
        trigger_treatment_list,
        output_event,
        probability_per_step=1.0, 
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='HSB'):
    """
    HSB
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    # First, get the objects
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    intervention = s2c.get_class_with_defaults( "SimpleHealthSeekingBehavior", schema_path ) 

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV", schema_path )
    #meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=duration
    meta_intervention.Trigger_Condition_List.extend(trigger_treatment_list)
    meta_intervention.Blackout_Period = black_period
    meta_intervention.Blackout_Event_Trigger = black_trigger
    meta_intervention.Property_Restrictions.extend(property_restrictions_list)
    meta_intervention.Actual_IndividualIntervention_Config = intervention
    meta_intervention.pop( "Actual_NodeIntervention_Config" )
    meta_intervention.pop( "Node_Property_Restrictions" )
    meta_intervention.pop( "Property_Restrictions_Within_Node" )

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_intervention

    # Third, do the actual settings
    event.Start_Day = float(start_day)
    intervention.Event_Or_Config = 'Event'
    intervention.Actual_IndividualIntervention_Event = output_event
    intervention.Tendency = probability_per_step
    #intervention.Duplicate_Policy = dupe_policy

    # Fourth/finally, purge the schema bits
    coordinator.finalize()
    intervention.finalize()
    meta_intervention.finalize()
    event.finalize()
    event["Name"] = event_name
    event["Listening"] = list()
    event["Listening"].extend( trigger_treatment_list )
    event["Listening"].append( black_trigger )
    event["Broadcasting"] = list()
    event["Broadcasting"].append( output_event )

    return event

def new_intervention_as_file( start_day, filename=None ):
    campaign = {}
    campaign["Events"] = []
    campaign["Events"].append( HSB( start_day, iv_name ) )
    if filename is None:
        filename = "hsb_diag.json"
    with open( filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return filename

