from emod_api import schema_to_class as s2c
import json

#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch


def RampDTN(
        camp,
        trigger_treatment_list,
        ramp_time=30,
        base_sensitivity_smearpos=1.0,
        base_sensitivity_smearneg=1.0,
        base_sensitivity_smearpos2=1.0,
        base_sensitivity_smearneg2=1.0,
        treatment_fraction=1.0,
        treatment_fraction2=1.0,
        pos_event= 'TBTestPositive',
        neg_event= 'TBTestNegative',
        defaulters_event='TBTestDefault',
        pos_event2='TBTestPositive',
        neg_event2='TBTestNegative',
        defaulters_event2='TBTestDefault',
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='RampDTN'):
    """
    RampDTN
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    # First, get the objects
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    intervention = s2c.get_class_with_defaults( "DiagnosticTreatNeg", schema_path )
    intervention2 = s2c.get_class_with_defaults( "DiagnosticTreatNeg", schema_path )

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIVScaleUpSwitch", schema_path )
    #meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=duration
    meta_intervention.Trigger_Condition_List.extend(trigger_treatment_list)
    meta_intervention.Blackout_Period = black_period
    meta_intervention.Blackout_Event_Trigger = black_trigger
    meta_intervention.Property_Restrictions.extend(property_restrictions_list)
    meta_intervention.Primary_Time_Constant = ramp_time
    meta_intervention.Demographic_Coverage_Time_Profile = 'Linear'
    meta_intervention.Initial_Demographic_Coverage = 0
    meta_intervention.Actual_IndividualIntervention_Config = intervention
    meta_intervention.Not_Covered_IndividualIntervention_Configs = [ intervention2 ]
    meta_intervention.pop("Node_Property_Restrictions")
    meta_intervention.pop("Property_Restrictions_Within_Node")

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_intervention
    event.Start_Day = float(start_day)

    # Third, do the actual settings
    intervention.Base_Sensitivity = base_sensitivity_smearpos
    intervention.Base_Specificity = 1.0 - base_sensitivity_smearneg
    intervention.Treatment_Fraction = treatment_fraction
    intervention.Event_Or_Config = 'Event'
    intervention.Positive_Diagnosis_Event = camp.get_event( pos_event )
    intervention.Negative_Diagnosis_Event = camp.get_event( neg_event )
    intervention.Defaulters_Event = camp.get_event( defaulters_event )

    intervention2.Base_Sensitivity = base_sensitivity_smearpos2
    intervention2.Base_Specificity = 1.0 - base_sensitivity_smearneg2
    intervention2.Treatment_Fraction = treatment_fraction2
    intervention2.Event_Or_Config = 'Event'
    intervention2.Positive_Diagnosis_Event = camp.get_event(pos_event2)
    intervention2.Negative_Diagnosis_Event = camp.get_event(neg_event2)
    intervention2.Defaulters_Event = camp.get_event(defaulters_event2)
    #intervention.Duplicate_Policy = dupe_policy

    # Fourth/finally, purge the schema bits
    coordinator.finalize()
    intervention.finalize()
    intervention2.finalize()
    meta_intervention.finalize()
    event.finalize()
    event["Name"] = event_name
    event["Listening"] = list()
    event["Listening"].extend( trigger_treatment_list )
    event["Listening"].append( black_trigger )
    event["Broadcasting"] = [ pos_event, neg_event, defaulters_event, pos_event2, neg_event2, defaulters_event2 ]

    return event

def new_intervention_as_file( start_day, filename=None ):
    campaign = {}
    campaign["Events"] = []
    campaign["Events"].append( new_intervention( start_day, vaccine_type, iv_name ) )
    if filename is None:
        filename = "ramp.json"
    with open( filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return filename

