from emod_api import schema_to_class as s2c
import json

#dupe_policy = "Replace" # or "Add" or "Abort" -- from covid branch

def TBDrugTreatment(
        camp,
        trigger_treatment_list,
        drug_name= 'DOTS',
        inactivation_rate=0,
        mortality_rate=0,
        clearance_rate=0,
        resistance_rate=0,
        relapse_rate=0,
        reduced_transmit=1.0,
        start_day=0,
        treatment_duration=180,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='TB Diagnosis Active Simple'):
    """
    TBDrugTreatment
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path
    # First, get the objects
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    intervention = s2c.get_class_with_defaults( "AntiTBDrug", schema_path )

    meta_intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV", schema_path )
    #meta_intervention.Demographic_Coverage=coverage
    meta_intervention.Duration=duration
    meta_intervention.Trigger_Condition_List.extend(trigger_treatment_list)
    meta_intervention.Blackout_Period = black_period
    meta_intervention.Blackout_Event_Trigger = black_trigger
    meta_intervention.Property_Restrictions.extend(property_restrictions_list)
    meta_intervention.Actual_IndividualIntervention_Config = intervention
    meta_intervention.pop("Actual_NodeIntervention_Config")
    meta_intervention.pop("Node_Property_Restrictions")
    meta_intervention.pop("Property_Restrictions_Within_Node")

    # Second, hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = meta_intervention
    event.Start_Day = float(start_day)

    # Third, do the actual settings
    intervention.Drug_Type = drug_name
    intervention.TB_Drug_Inactivation_Rate = inactivation_rate
    #intervention.TB_Drug_Clearance_Rate = clearance_rate
    intervention.TB_Drug_Resistance_Rate = resistance_rate
    intervention.TB_Drug_Relapse_Rate = relapse_rate
    intervention.TB_Drug_Mortality_Rate = mortality_rate
    intervention.Reduced_Transmit = reduced_transmit
    intervention.Durability_Profile = 'FIXED_DURATION_CONSTANT_EFFECT'
    intervention.Primary_Decay_Time_Constant = treatment_duration
    #intervention.Duplicate_Policy = dupe_policy

    # Fourth/finally, purge the schema bits
    coordinator.finalize()
    intervention.finalize()
    meta_intervention.finalize()
    event.finalize()
    event["Name"] = event_name
    event["Listening"] = list()
    event["Listening"].extend( trigger_treatment_list )
    event["Listening"].append( black_trigger )

    return event

def new_intervention_as_file( start_day, filename=None ):
    campaign = {}
    campaign["Events"] = []
    campaign["Events"].append( new_intervention( start_day, vaccine_type, iv_name ) )
    if filename is None:
        filename = "tb_drug_treat.json"
    with open( filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return filename

