#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.art as art
import emod_api.campaign as camp


class TestART(TestIntervention):
    """
    Test ARTBasic intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(art.ART, "ARTBasic", "camp_art.json")

    def test_all(self):
        camp.schema_path = self.schema
        trigger_treatment_list = ['infected']
        start_day = 10
        duration = 100
        property_restrictions_list = ['Demo: 1']
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 20
        black_trigger = 'Blackout'
        event_name = 'ART'
        event = art.ART(camp, trigger_treatment_list, start_day, duration, property_restrictions_list, nodeIDs,
                        black_period, black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_art.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertEqual(ic["Property_Restrictions"], expected_property_restrictions_list)
        self.assertEqual(ic["Duration"], duration)
        self.assertEqual(ic["Blackout_Period"], black_period)
        self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)


if __name__ == '__main__':
    unittest.main()

