#!/usr/bin/env python
import os
import unittest
import copy
import json
from intervention_test import TestIntervention
import manifest

import emodpy_tbhiv.interventions.hsb as hsb
import emod_api.campaign as camp


class Testhsb(TestIntervention):
    """
    Test SimpleHealthSeekingBehavior intervention
    """
    def test_default(self):
        super().trigger_treatment_list_with_output_event_test(hsb.HSB, 'GP_EVENT_001',
                                                              'SimpleHealthSeekingBehavior', 'camp_hsb.json')

    def test_all(self):
        camp.schema_path = self.schema
        trigger_treatment_list = ['infected']
        output_event = 'GP_EVENT_000'
        probability_per_step = 0.1
        start_day = 1
        duration = 9
        property_restrictions_list = ['Demo: 6']
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 0
        black_trigger = 'Blackout'
        event_name = 'HSB'
        event = hsb.HSB(camp, trigger_treatment_list, output_event, probability_per_step, start_day, duration,
                        property_restrictions_list, nodeIDs, black_period, black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_hsb.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention = ic["Actual_IndividualIntervention_Config"]

        self.assertEqual(intervention["Tendency"], probability_per_step)

        self.assertEqual(ic["Property_Restrictions"], expected_property_restrictions_list)
        self.assertEqual(ic["Duration"], duration)
        self.assertEqual(ic["Blackout_Period"], black_period)
        self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(camp.pubsub_signals_pubbing, [output_event])


if __name__ == '__main__':
    unittest.main()

