#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.tb_treat_basic as tbt
import emod_api.campaign as camp


class Testtbtreat(TestIntervention):
    """
    Test AntiTBDrug intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(tbt.TBDrugTreatment, "AntiTBDrug", "camp_tbtreat.json")

    def test_all(self):
        camp.schema_path = self.schema
        trigger_treatment_list = ['infected']
        drug_name= 'DOTS'
        inactivation_rate=0.1
        mortality_rate=0.1
        clearance_rate=0.1
        resistance_rate=0.1
        relapse_rate=0.1
        reduced_transmit=0.9
        start_day=4
        treatment_duration=160
        duration=200
        property_restrictions_list = ["Risk: HIGH"]
        nodeIDs=[]
        black_period=10
        black_trigger='Blackout'
        event_name='TB Treatment Simple'
        event = tbt.TBDrugTreatment(camp, trigger_treatment_list, drug_name, inactivation_rate,
                                         mortality_rate, clearance_rate, resistance_rate, 
                                         relapse_rate, reduced_transmit, start_day, treatment_duration, 
                                         duration, property_restrictions_list, nodeIDs, black_period,
                                         black_trigger, event_name)


        camp.campaign_dict["Events"] = []
        camp.add(event)
        camp_filename = os.path.join(self.output, "tb_treat.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Drug_Type"], drug_name)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["TB_Drug_Inactivation_Rate"], inactivation_rate)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["TB_Drug_Mortality_Rate"], mortality_rate)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["TB_Drug_Resistance_Rate"], resistance_rate)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["TB_Drug_Relapse_Rate"], relapse_rate)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Reduced_Transmit"], reduced_transmit)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(ic["Duration"], duration)   
        self.assertEqual(ic["Property_Restrictions"], copy.deepcopy(property_restrictions_list))
        self.assertEqual(ic["Blackout_Period"], black_period)
        self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)


if __name__ == '__main__':
    unittest.main()

