#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.triggered_pvc as tpvc
import emod_api.campaign as camp


class Testtpvc(TestIntervention):
    """
    Test PropertyValueChanger intervention
    """
    def test_default(self):
        super().trigger_treatment_list_with_properties_test(tpvc.TPVC, "StartFakePropKey", "StopFakePropKey",
                                                            "PropertyValueChanger", "camp_tpvc.json")

    def test_all(self):
        camp.schema_path = self.schema
        trigger_treatment_list = ['infected']
        property_to_change = ["bing"]
        final_prop_value, = ["bang"]
        revert=1
        daily_prob=0.5
        start_day=5
        duration=25
        property_restrictions_list = ["Risk: HIGH"]
        nodeIDs=[]
        black_period=13
        black_trigger='Blackout'
        event_name='ART'

        event = tpvc.TPVC(camp, trigger_treatment_list, property_to_change, final_prop_value,
                                         revert, daily_prob, start_day,
                                         duration, property_restrictions_list, nodeIDs, black_period,
                                        black_trigger, event_name)

        camp.campaign_dict["Events"] = []
        camp.add(event)
        camp_filename = os.path.join(self.output, "camp_tpvc.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Target_Property_Key"], property_to_change)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Target_Property_Value"], final_prop_value)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Revert"], revert)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Daily_Probability"], daily_prob)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(ic["Duration"], duration)   
        self.assertEqual(ic["Property_Restrictions"], copy.deepcopy(property_restrictions_list))
        self.assertEqual(ic["Blackout_Period"], black_period)
        self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)



if __name__ == '__main__':
    unittest.main()

