#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.vaccine as vacc
import emod_api.campaign as camp



class Testvacc(TestIntervention):
    """
    Test SimpleVaccine intervention
    """
    def test_default(self):
        super().trigger_treatment_list_test(vacc.Vaccine, "SimpleVaccine", "camp_vacc.json")

    def test_all(self):
        camp.schema_path = self.schema
        trigger_treatment_list = ['infected']
        initial_efficacy = 0.9
        vaccine_take = 0
        vtype = 'AcquisitionBlocking'
        box_duration = 366
        immune_decay = 3651
        start_day = 2
        duration = 70
        property_restrictions_list = ["Risk: HIGH"]
        nodeIDs = []
        black_period = 11
        black_trigger = 'Blackout'
        event_name = 'Vaccine'

        event = vacc.Vaccine(camp, trigger_treatment_list, initial_efficacy, vaccine_take, vtype, box_duration,
                             immune_decay, start_day, duration, property_restrictions_list, nodeIDs, black_period,
                             black_trigger, event_name)

        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_vacc.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)

        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Waning_Config"]['Initial_Effect'], initial_efficacy)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Vaccine_Take"], vaccine_take)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Vaccine_Type"], vtype)        
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Waning_Config"]['Box_Duration'], box_duration)
        self.assertEqual(ic["Actual_IndividualIntervention_Config"]["Waning_Config"]['Decay_Time_Constant'], immune_decay)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)
        self.assertEqual(ic["Duration"], duration)   
        self.assertEqual(ic["Property_Restrictions"], copy.deepcopy(property_restrictions_list))
        self.assertEqual(ic["Blackout_Period"], black_period)
        self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
if __name__ == '__main__':
    unittest.main()

